@@ -321,7 +321,7 @@ OGRLayer *OGRElasticDataSource::GetLayerByName(const char *pszName)
         return nullptr;
 
     m_apoLayers.push_back(
-        cpl::make_unique<OGRElasticLayer>(pszName, poReferenceLayer));
+        std::make_unique<OGRElasticLayer>(pszName, poReferenceLayer));
     return m_apoLayers.back().get();
 }
 
@@ -412,10 +412,10 @@ OGRErr OGRElasticDataSource::DeleteLayer(int iLayer)
 /*                           ICreateLayer()                             */
 /************************************************************************/
 
-OGRLayer *OGRElasticDataSource::ICreateLayer(const char *pszLayerName,
-                                             const OGRSpatialReference *poSRS,
-                                             OGRwkbGeometryType eGType,
-                                             char **papszOptions)
+OGRLayer *
+OGRElasticDataSource::ICreateLayer(const char *pszLayerName,
+                                   const OGRGeomFieldDefn *poGeomFieldDefn,
+                                   CSLConstList papszOptions)
 {
     if (eAccess != GA_Update)
     {
@@ -424,6 +424,10 @@ OGRLayer *OGRElasticDataSource::ICreateLayer(const char *pszLayerName,
         return nullptr;
     }
 
+    const auto eGType = poGeomFieldDefn ? poGeomFieldDefn->GetType() : wkbNone;
+    const auto poSRS =
+        poGeomFieldDefn ? poGeomFieldDefn->GetSpatialRef() : nullptr;
+
     CPLString osLaunderedName(pszLayerName);
 
     const char *pszIndexName = CSLFetchNameValue(papszOptions, "INDEX_NAME");
